# bareutils

Utilities for [bareASGI](https://github.com/rob-blackbourn/bareASGI)
and [bareClient](https://github.com/rob-blackbourn/bareClient)
(read the [docs](https://rob-blackbourn.github.io/bareUtils/)).

## Installation

The package can be installed with pip.

```bash
pip install bareutils
```

This is a Python3.7 and later package.

It has dependencies on:

* [bareTypes](https://github.com/rob-blackbourn/bareTypes)
